==> eagle-i-repository-webapp-1.0-MS6.09-sources.jar: jsp/repository/admin/restoreDbIfc_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import org.eaglei.repository.DataRepository;
import org.eaglei.repository.DataRepository;

public final class restoreDbIfc_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList(1);
    _jspx_dependants.add("/repository/admin/banner.jsp");
  }

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("<!--\n   The Eagle-I Data Repository backup GUI page.\n-->\n\n");
      org.eaglei.repository.admin.AuthAdminBean adminBean = null;
      synchronized (session) {
        adminBean = (org.eaglei.repository.admin.AuthAdminBean) _jspx_page_context.getAttribute("adminBean", PageContext.SESSION_SCOPE);
        if (adminBean == null){
          adminBean = new org.eaglei.repository.admin.AuthAdminBean();
          _jspx_page_context.setAttribute("adminBean", adminBean, PageContext.SESSION_SCOPE);
        }
      }
      out.write('\n');
      org.apache.jasper.runtime.JspRuntimeLibrary.handleSetProperty(_jspx_page_context.findAttribute("adminBean"), "request",
 request );
      out.write("\n\n<html>\n  <head>\n    <title>Eagle-I Administration - Database Backup</title>\n  </head>\n    <body bgcolor=lightyellow>\n    ");
      out.write("\n\n\n<hr/>\n    <table border=\"0\" width=\"100%\" >\n      <tr>\n        <td width=\"30%\"><a href=\"http://www.eagle-i.org/\"><img border=\"0\" alt=\"Institutional Logo\" align=\"right\"\n               src=\"");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.logo", "/repository/images/eagle-i_admin_logo.png") );
      out.write("\" /></a>\n        </td>\n        <td width=\"40%\"><div align=\"center\">\n          <font size=\"+2\" color=\"black\">\n            Repository Administration Area\n          </font>\n          <p>");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.title", "(Config property <tt>eaglei.repository.title</tt> needs to be set)") );
      out.write("</p>\n        </div></td>\n        <td width=\"30%\">&nbsp;</td>\n      </tr>\n    </table>\n<hr/>\n");
      out.write("\n        <h3>Authentication Database Restore</h3>\n        <p>A restore through this page will replace the current authentication database with the data from the selected backup dataset.\n        Only authentication data will be restored, RDF data for the repository itself is not effected by this process.</p>\n        <h4>Select an authentication database backup from the list:</h4>\n        <form method=\"POST\" action=\"/repository/admin/restore.jsp\" >\n          <table border=\"0\" cellspacing=\"5\">\n            <tr>\n              <th valign=top align=right><tt><b>");
      out.print( DataRepository.getInstance().getBackupDirectory().toString() );
      out.write("/</tt></b></th>\n              <td align=\"left\"><SELECT NAME=\"backupDir\" SIZE=20>\n");

   java.util.ArrayList<String> list = adminBean.getBACKUPList();
   if (list.isEmpty()){
      out.println("<OPTION><i>&lt;directory is empty&gt;</i></OPTION>");
   } else {
      java.util.Iterator<String> itr = list.iterator();
      while (itr.hasNext()) {
         String fname = itr.next();
         out.println( "<OPTION> " + String.valueOf( fname ) + "</OPTION>");
      }
   }

      out.write("\n      </SELECT></td>\n            </tr>\n            <tr>\n              <td align=\"right\"><input type=\"reset\"></td>\n              <td align=\"left\"><input type=\"submit\" value=\"Restore now!\"></td>\n            </tr>\n          </table>\n        </form>\n  </body>\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}

==> eagle-i-repository-webapp-1.1-MS2.02-sources.jar: jsp/repository/admin/restoreDbIfc_jsp.java <==
package jsp.repository.admin;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import org.eaglei.repository.DataRepository;
import org.eaglei.repository.DataRepository;

public final class restoreDbIfc_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList(1);
    _jspx_dependants.add("/repository/admin/banner.jsp");
  }

  private javax.el.ExpressionFactory _el_expressionfactory;
  private org.apache.AnnotationProcessor _jsp_annotationprocessor;

  public Object getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _el_expressionfactory = _jspxFactory.getJspApplicationContext(getServletConfig().getServletContext()).getExpressionFactory();
    _jsp_annotationprocessor = (org.apache.AnnotationProcessor) getServletConfig().getServletContext().getAttribute(org.apache.AnnotationProcessor.class.getName());
  }

  public void _jspDestroy() {
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;


    try {
      response.setContentType("text/html;charset=UTF-8");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;

      out.write("<!--\n   The Eagle-I Data Repository backup GUI page.\n-->\n\n");
      org.eaglei.repository.admin.AuthAdminBean adminBean = null;
      synchronized (session) {
        adminBean = (org.eaglei.repository.admin.AuthAdminBean) _jspx_page_context.getAttribute("adminBean", PageContext.SESSION_SCOPE);
        if (adminBean == null){
          adminBean = new org.eaglei.repository.admin.AuthAdminBean();
          _jspx_page_context.setAttribute("adminBean", adminBean, PageContext.SESSION_SCOPE);
        }
      }
      out.write('\n');
      org.apache.jasper.runtime.JspRuntimeLibrary.handleSetProperty(_jspx_page_context.findAttribute("adminBean"), "request",
 request );
      out.write("\n\n<html>\n  <head>\n    <title>Eagle-I Administration - Database Backup</title>\n  </head>\n    <body bgcolor=lightyellow>\n    ");
      out.write('\n');
      out.write("\n\n<hr/>\n    <table border=\"0\" width=\"100%\" >\n      <tr>\n        <td width=\"30%\"><a href=\"http://www.eagle-i.org/\"><img border=\"0\" alt=\"Institutional Logo\" align=\"right\"\n               src=\"");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.logo", "/repository/images/eagle-i_admin_logo.png") );
      out.write("\" /></a>\n        </td>\n        <td width=\"40%\"><div align=\"center\">\n          <font size=\"+2\" color=\"black\">\n            Repository Administration Area\n          </font>\n          <p>");
      out.print( DataRepository.getInstance().getConfigurationProperty("eaglei.repository.title", "(Config property <tt>eaglei.repository.title</tt> needs to be set)") );
      out.write("</p>\n        </div></td>\n        <td width=\"30%\">&nbsp;</td>\n      </tr>\n    </table>\n<hr/>\n");
      out.write("\n        <h3>Authentication Database Restore</h3>\n        <p>A restore through this page will replace the current authentication database with the data from the selected backup dataset.\n        Only authentication data will be restored, RDF data for the repository itself is not effected by this process.</p>\n        <h4>Select an authentication database backup from the list:</h4>\n        <form method=\"POST\" action=\"/repository/admin/restore.jsp\" >\n          <table border=\"0\" cellspacing=\"5\">\n            <tr>\n              <th valign=top align=right><tt><b>");
      out.print( DataRepository.getInstance().getBackupDirectory().toString() );
      out.write("/</tt></b></th>\n              <td align=\"left\"><SELECT NAME=\"backupDir\" SIZE=20>\n");

   java.util.ArrayList<String> list = adminBean.getBACKUPList();
   if (list.isEmpty()){
      out.println("<OPTION><i>&lt;directory is empty&gt;</i></OPTION>");
   } else {
      java.util.Iterator<String> itr = list.iterator();
      while (itr.hasNext()) {
         String fname = itr.next();
         out.println( "<OPTION> " + String.valueOf( fname ) + "</OPTION>");
      }
   }

      out.write("\n      </SELECT></td>\n            </tr>\n            <tr>\n              <td align=\"right\"><input type=\"reset\"></td>\n              <td align=\"left\"><input type=\"submit\" value=\"Restore now!\"></td>\n            </tr>\n          </table>\n        </form>\n  </body>\n</html>\n");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          try { out.clearBuffer(); } catch (java.io.IOException e) {}
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }
}
